cryptography_flutter library
An optimized version of package:cryptography.
See FlutterCryptography for usage instructions.
Classes
- BackgroundAesGcm
-
AesGcmthat's optimized to use compute. - BackgroundChacha
-
Chacha20.poly1305Aeadthat's optimized to use compute. - BackgroundCipher
- Base class for ciphers that use background workers.
- BackgroundPbkdf2
-
Pbkdf2that's optimized to use compute. - CryptographyChannelCall
- CryptographyChannelPolicy
- Describes when to pass computation to plugin or another isolate.
- CryptographyChannelQueue
- Waiting group used for preventing copying too much data to a channel such as compute channel or MethodChannel.
- FlutterAesGcm
-
AesGcmthat uses platform APIs in Android, iOS, and Mac OS X. - FlutterChacha20
-
Chacha20that uses platform APIs in Android, iOS, and Mac OS X. - FlutterCipher
-
Superclass for
Cipherclasses that use platform APIs. - FlutterCryptography
-
An implementation
Cryptographythat uses native operating system APIs. - FlutterEcdh
-
Ecdhthat uses platform APIs in Android, iOS, and Mac OS X. - FlutterEcdsa
-
Ecdsathat uses platform APIs in Android, iOS, and Mac OS X. - FlutterEd25519
-
Ed25519that uses platform APIs in Android, iOS, and Mac OS X. - FlutterPbkdf2
-
Pbkdf2that uses platform APIs in Android. - FlutterRsaPss
-
RsaPssthat uses platform APIs in Android. - FlutterRsaSsaPkcs1v15
-
RsaSsaPkcs1v15that uses platform APIs in Android. - FlutterX25519
-
X25519that uses platform APIs in Android, iOS, and Mac OS X.