FlutterEcdh class

Ecdh that uses platform APIs in Android, iOS, and Mac OS X.

Constructors

FlutterEcdh.p256({int length = 32, String? androidCryptoProvider, Ecdh? fallback})
ECDH-P256
FlutterEcdh.p384({int length = 32, String? androidCryptoProvider, Ecdh? fallback})
ECDH-P384
FlutterEcdh.p521({int length = 32, String? androidCryptoProvider, Ecdh? fallback})
ECDH-P521

Properties

androidCryptoProvider → String?
Optional Android provider name (such as "BC").
final
fallback → Ecdh?
Fallback implementation.
final
hashCode → int
The hash code for this object.
no setterinherited
isSupportedPlatform → bool
Whether this algorithm is expected to be able to use platform APIs.
no setter
keyPairType → KeyPairType<KeyPairData, PublicKey>
final
length → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

newKeyExchangeWand() → Future<KeyExchangeWand>
Returns a new KeyExchangeWand that has a random KeyPair.
inherited
newKeyExchangeWandFromKeyPair(KeyPair keyPair) → Future<KeyExchangeWand>
Returns a new KeyExchangeWand that uses the given KeyPair.
inherited
newKeyPair() → Future<EcKeyPair>
Generates a new KeyPair that can be used with this algorithm.
newKeyPairFromSeed(List<int> seed) → Future<EcKeyPair>
Generates a key pair from the seed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sharedSecretKey({required KeyPair keyPair, required PublicKey remotePublicKey}) → Future<SecretKey>
Calculates a shared SecretKey.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited